﻿using AndDietCokeContract.Exceptions;
using AndDietCokeContract.Extensions;
using AndDietCokeContract.Infrastructure;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Xml;

namespace AndDietCokeContract.DataModels;

public class SaleDataModel(string id, string workerId, string? buyerId, double
sum, double bonuses, bool isCancel,
List<SaleDishDataModel> dishes) : IValidation
{
    public string Id { get; private set; } = id;
    public string WorkerId { get; private set; } = workerId;
    public string? BuyerId { get; private set; } = buyerId;
    public DateTime SaleDate { get; private set; } = DateTime.UtcNow;
    public double Sum { get; private set; } = sum;
    public double Bonuses { get; private set; } = bonuses;
    public bool IsCancel { get; private set; } = isCancel;
    public List<SaleDishDataModel> Dishes { get; private set; } = dishes;
    public void Validate()
    {
        if (Id.IsEmpty())
            throw new ValidationException("Field Id is empty");
        if (!Id.IsGuid())
            throw new ValidationException("The value in the field Id is not a unique identifier");
        if (WorkerId.IsEmpty())
            throw new ValidationException("Field WorkerId is empty");
        if (!WorkerId.IsGuid())
            throw new ValidationException("The value in the field WorkerId is not a unique identifier");
        if (!BuyerId?.IsGuid() ?? !BuyerId?.IsEmpty() ?? false)
            throw new ValidationException("The value in the field BuyerId is not a unique identifier");
        if (Sum <= 0)
            throw new ValidationException("Field Sum is less than or equal to 0");
        if ((Dishes?.Count ?? 0) == 0)
            throw new ValidationException("The sale must include dishes");
    }
}
